@@ -5,7 +5,7 @@
 #' @param type  The type of end point. Options include \code{data}, \code{meta-data}, and \code{actions}
 #' @return \code{list}
 #' @export
-#' @importFrom httr GET content stop_for_status
+#' @importFrom httr GET content warn_for_status
 #' @importFrom plyr ldply 
 #' @importFrom RJSONIO fromJSON
 #' @examples  
@@ -17,9 +17,9 @@
 #' ee_about(type = "meta-data")
 #' ee_about(type = "actions")
 ee_about <- function(as.df = TRUE, type = NA) {
-about_url <- "http://ecoengine.berkeley.edu/api/?format=json" 
+about_url <- paste0(ee_base_url(), "?format=json")
 about_call <- GET(about_url)
-stop_for_status(about_call)
+warn_for_status(about_call)
 about <- content(about_call)
 if(!as.df) {
     return(about)
@@ -40,5 +40,4 @@ if(!as.df) {
         return(about_df)
 
 }
-
 } 
\ No newline at end of file
